import{af as f,Y as t,V as d,f as p}from"./outputWidgets.52571dac.js";import{B as l,b as c}from"./Base.e64db743.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="da2ec811-44fd-402b-aca1-87eedb30fa61",e._sentryDebugIdIdentifier="sentry-dbid-da2ec811-44fd-402b-aca1-87eedb30fa61")}catch{}})();const b=()=>t(t({},d(c(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),a=(e,s)=>{let{slots:o,attrs:r}=s;const{ellipsis:n}=e;f();const i=t(t(t({},e),{ellipsis:n&&typeof n=="object"?d(n,["expandable","rows"]):n,component:"span"}),r);return p(l,i,o)};a.displayName="ATypographyText";a.inheritAttrs=!1;a.props=b();const g=a;export{g as A};
//# sourceMappingURL=Text.0586c869.js.map
