import{_ as B}from"./logo.084e5d7c.js";import{E as x,b as r,ey as _,eE as C,eF as w,e as i,d as k,eM as N,a as S,u as e,c,bj as $,f as o,w as t,au as n,bI as d,eJ as f,cG as D,cC as L,D as z,eH as E,f9 as V,aG as b,eA as F,dq as G}from"./outputWidgets.52571dac.js";import{a as R}from"./asyncComputed.2a2a1288.js";import{G as T}from"./PhChats.vue.ba664239.js";import{F as j}from"./PhSignOut.vue.2dbc88f8.js";import{C as q}from"./router.0ae1ef4a.js";import{a as h}from"./gateway.9b472f57.js";import{A as H}from"./Text.0586c869.js";import{A as M}from"./index.07ea88e4.js";import{B as P,A as J,b as O}from"./index.c074fcff.js";import{B as U}from"./BookOutlined.7e4ac738.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[a]="84cad5ee-25e4-455e-9032-188b1f73e5f4",s._sentryDebugIdIdentifier="sentry-dbid-84cad5ee-25e4-455e-9032-188b1f73e5f4")}catch{}})();const K={},v=s=>(C("data-v-46e041c1"),s=s(),w(),s),Q={class:"logo"},W=v(()=>i("img",{class:"logo-img",src:B,alt:"Abstra cloud logo"},null,-1)),X=v(()=>i("span",null,"Abstra",-1)),Y=[W,X];function Z(s,a){return r(),_("div",Q,Y)}const ee=x(K,[["render",Z],["__scopeId","data-v-46e041c1"]]),te={key:1,style:{display:"flex","align-items":"center",gap:"16px"}},oe={style:{display:"flex","flex-direction":"column",gap:"10px"}},se={style:{display:"flex",gap:"5px"}},ae=k({__name:"LoginBlock",setup(s){function a(g){const y=g.split("@")[0];return z.exports.kebabCase(y).toUpperCase().split("-").slice(0,2).map(m=>m[0]).join("")}const p=N(),{result:l,loading:u,refetch:A}=R(async()=>h.getAuthor());function I(){h.removeAuthor(),q.shutdown(),A(),p.push({name:"login"})}return(g,y)=>{const m=S("router-link");return e(u)?(r(),c(e($),{key:0})):e(l)?(r(),_("div",te,[o(e(d),{class:"intercom-launcher",target:"_blank",type:"link",size:"small",style:{color:"#d14056",display:"flex","align-items":"center",gap:"6px"}},{icon:t(()=>[o(e(T),{size:18})]),default:t(()=>[n(" Support ")]),_:1}),o(e(L),{placement:"bottomRight"},{content:t(()=>[i("div",oe,[o(e(H),{size:"small",type:"secondary"},{default:t(()=>[n(f(e(l).claims.email),1)]),_:1}),o(e(d),{type:"text",onClick:I},{default:t(()=>[i("div",se,[o(e(j),{size:"20"}),n(" Logout ")])]),_:1})])]),default:t(()=>[o(e(D),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[o(e(M),{shape:"square"},{default:t(()=>[n(f(a(e(l).claims.email)),1)]),_:1})]),_:1})]),_:1})])):(r(),c(e(d),{key:2},{default:t(()=>[o(m,{to:"/login"},{default:t(()=>[n("Login")]),_:1})]),_:1}))}}}),re={class:"extra"},ne=k({__name:"Navbar",props:{breadcrumb:{}},setup(s){return(a,p)=>(r(),c(e(O),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[a.breadcrumb?(r(),c(e(P),{key:0,style:{margin:"0px 50px"}},{default:t(()=>[(r(!0),_(b,null,E(a.breadcrumb,(l,u)=>(r(),c(e(J),{key:u},{default:t(()=>[o(e(V),{to:l.path},{default:t(()=>[n(f(l.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):F("",!0)]),title:t(()=>[o(ee)]),extra:t(()=>[i("div",re,[o(e(d),{class:"docs-button",href:"https://docs.abstra.io/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[o(e(U))]),default:t(()=>[a.$slots.default?G(a.$slots,"default",{key:0},void 0,!0):(r(),_(b,{key:1},[n("Docs")],64))]),_:3}),o(ae)])]),_:3}))}});const be=x(ne,[["__scopeId","data-v-31e2a422"]]);export{be as N};
//# sourceMappingURL=Navbar.a2e969a3.js.map
