import{a as g}from"./asyncComputed.2a2a1288.js";import{d as y,eG as _,o as b,u as e,b as p,c as w,ey as x,f as a,w as o,au as l,bI as C,e as I,eJ as h}from"./outputWidgets.52571dac.js";import"./gateway.9b472f57.js";import"./index.803d0576.js";import{O as k}from"./organization.6ceb5620.js";import{C as m}from"./router.0ae1ef4a.js";import{L as v}from"./LoadingContainer.d88aed31.js";import{A}from"./Title.8fbc2e7d.js";import{A as B}from"./index.89edc4ba.js";import{A as D}from"./index.6763f634.js";import{C as N}from"./Card.d78b977b.js";import"./popupNotifcation.e85fac74.js";import"./record.2a93f29c.js";import"./pubsub.be7004e9.js";import"./Form.9e43a28b.js";import"./hasIn.f1c353ba.js";import"./Base.e64db743.js";import"./TabPane.dea34545.js";import"./PlusOutlined.cf52d035.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="3003e06f-f337-4e3b-adac-975c2be56299",t._sentryDebugIdIdentifier="sentry-dbid-3003e06f-f337-4e3b-adac-975c2be56299")}catch{}})();const z={key:1},M={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},$=y({__name:"Billing",setup(t){const n=_().params.organizationId,{loading:f,result:c}=g(()=>k.get(n));b(()=>{location.search.includes("upgrade")&&m.showNewMessage("I want to upgrade my plan")});const u=()=>m.showNewMessage("I want to upgrade my plan");return(V,j)=>e(f)?(p(),w(v,{key:0})):(p(),x("div",z,[a(e(B),{justify:"space-between",align:"center"},{default:o(()=>[a(e(A),{level:3},{default:o(()=>[l("Current plan")]),_:1})]),_:1}),a(e(D),{style:{"margin-top":"0"}}),a(e(N),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(C),{onClick:u},{default:o(()=>[l("Upgrade")]),_:1})]),default:o(()=>{var s,i,d;return[I("div",M,h((d=(i=(s=e(c))==null?void 0:s.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{$ as default};
//# sourceMappingURL=Billing.15b9d062.js.map
