import{g as _}from"./api.66aa9b15.js";import{i as g}from"./metadata.baee0e00.js";import{a as h}from"./asyncComputed.2a2a1288.js";import{W as b}from"./WidgetsFrame.6587888f.js";import{F as k}from"./PhArrowSquareOut.vue.f02622b6.js";import{d as w,eM as x,y as v,u as e,b as o,c as i,w as r,eA as C,au as d,ey as F,eH as I,f as l,eI as D,eJ as H,aG as T,E as V}from"./outputWidgets.52571dac.js";import"./index.1b528fc3.js";import{A as f}from"./index.89edc4ba.js";import"./index.ff625976.js";import{a as u}from"./Base.e64db743.js";import{C as A}from"./Card.d78b977b.js";import"./index.8b944c64.js";import"./fetch.9dae2a64.js";import"./pubsub.be7004e9.js";import"./runnerData.3982af84.js";import"./url.5cc70021.js";import"./PhCheckCircle.vue.67b14c02.js";import"./PhKanban.vue.bce4e3b1.js";import"./PhScroll.vue.9f99ffd4.js";import"./PhWebhooksLogo.vue.5cbb3f37.js";import"./Link.a6766c40.js";import"./Paragraph.7aa2ce32.js";import"./Text.0586c869.js";import"./Title.8fbc2e7d.js";import"./TabPane.dea34545.js";import"./hasIn.f1c353ba.js";import"./PlusOutlined.cf52d035.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="bd18c140-8536-4f67-8720-f0293a12070f",a._sentryDebugIdIdentifier="sentry-dbid-bd18c140-8536-4f67-8720-f0293a12070f")}catch{}})();const B=w({__name:"Home",setup(a){const n=x(),{result:t}=h(_),c=v(()=>{var s,p;return(p=(s=t.value)==null?void 0:s.sidebar)!=null?p:[]}),y=s=>{n.push({path:`/${s}`})};return(s,p)=>e(t)?(o(),i(b,{key:0,class:"runner","main-color":e(t).mainColor,theme:e(t).theme,"font-family":e(t).fontFamily},{default:r(()=>[c.value.length===0?(o(),i(e(u),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[d(" There is no public form available for you here. ")]),_:1})):(o(),i(e(f),{key:1,vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[(o(!0),F(T,null,I(c.value,m=>(o(),i(e(A),{key:m.id,class:"form-card",onClick:E=>y(m.path)},{default:r(()=>[l(e(f),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(o(),i(D(e(g)(m.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),l(e(u),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[d(H(m.name),1)]),_:2},1024),l(e(k),{color:"#000",width:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}))]),_:1},8,["main-color","theme","font-family"])):C("",!0)}});const ne=V(B,[["__scopeId","data-v-7d0e0e50"]]);export{ne as default};
//# sourceMappingURL=Home.758b247a.js.map
