import{d as t,b as o,ey as s,f as d,u as r,bj as _,E as c}from"./outputWidgets.52571dac.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9c4982c9-e807-4a8d-a9fa-a5a358e73154",e._sentryDebugIdIdentifier="sentry-dbid-9c4982c9-e807-4a8d-a9fa-a5a358e73154")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",i,[d(r(_))]))}});const u=c(f,[["__scopeId","data-v-1da18eee"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.d88aed31.js.map
