import{d as o,b as s,ey as a,e as d,dq as r,eC as l,E as f}from"./outputWidgets.52571dac.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4339fd45-e066-44df-96f7-ac70ab930877",e._sentryDebugIdIdentifier="sentry-dbid-4339fd45-e066-44df-96f7-ac70ab930877")}catch{}})();const _={class:"content-layout"},c=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,n)=>(s(),a("div",_,[d("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const i=f(c,[["__scopeId","data-v-00ef87a4"]]);export{i as C};
//# sourceMappingURL=ContentLayout.34675bf7.js.map
