import{E as d,b as o,ey as n,dq as s,e as a,eA as r}from"./outputWidgets.52571dac.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8e4e2107-55b8-459f-9139-b1f8a5d1e206",e._sentryDebugIdIdentifier="sentry-dbid-8e4e2107-55b8-459f-9139-b1f8a5d1e206")}catch{}})();const f={},c={class:"base-layout"},i={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),n("div",c,[s(e.$slots,"navbar",{},void 0,!0),a("section",i,[s(e.$slots,"sidebar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0)]),e.$slots.footer?(o(),n("section",u,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])}const y=d(f,[["render",_],["__scopeId","data-v-e54815f3"]]);export{y as B};
//# sourceMappingURL=BaseLayout.2bb1ac6f.js.map
