import{O as d}from"./index.8b944c64.js";import{d as i,o as l,b as u,ey as c,f as a,w as o,u as r,au as n}from"./outputWidgets.52571dac.js";import{A as f}from"./Title.8fbc2e7d.js";import{A as m}from"./Text.0586c869.js";import"./fetch.9dae2a64.js";import"./pubsub.be7004e9.js";import"./Base.e64db743.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ec8af710-65ef-4a19-a412-265441384c9d",e._sentryDebugIdIdentifier="sentry-dbid-ec8af710-65ef-4a19-a412-265441384c9d")}catch{}})();const I=i({__name:"OidcLogoutCallback",setup(e){return l(async()=>{await new d().logoutCallback()}),(t,s)=>(u(),c("div",null,[a(r(f),null,{default:o(()=>[n("You're authenticated")]),_:1}),a(r(m),null,{default:o(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{I as default};
//# sourceMappingURL=OidcLogoutCallback.8fb6cbfc.js.map
