import{e_ as t,e$ as d}from"./outputWidgets.52571dac.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="962b6ce5-697e-443b-acdf-eef0d7dfb276",e._sentryDebugIdIdentifier="sentry-dbid-962b6ce5-697e-443b-acdf-eef0d7dfb276")}catch{}})();function o(e,n){return t(1,arguments),d(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.88e4e5a7.js.map
