import{cA as n}from"./outputWidgets.52571dac.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="07c88cdc-bee5-4e98-a6d4-8c0eeef2831c",e._sentryDebugIdIdentifier="sentry-dbid-07c88cdc-bee5-4e98-a6d4-8c0eeef2831c")}catch{}})();const t=(e,r,d)=>{n.error({message:e,description:r,onClick:d})};export{t as p};
//# sourceMappingURL=popupNotifcation.e85fac74.js.map
