import{B as n,R as t}from"./Badge.08d6e243.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="6a3e978a-6ad1-4408-ba0d-73c715649951",e._sentryDebugIdIdentifier="sentry-dbid-6a3e978a-6ad1-4408-ba0d-73c715649951")}catch{}})();n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.9ddaf573.js.map
