import{F as t}from"./Form.9e43a28b.js";import{b5 as d,cp as n}from"./outputWidgets.52571dac.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="dcf9b2fe-9f1c-4df4-9a23-94d1dcb25580",e._sentryDebugIdIdentifier="sentry-dbid-dcf9b2fe-9f1c-4df4-9a23-94d1dcb25580")}catch{}})();t.useInjectFormItemContext=d;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.64231e4f.js.map
