.container[data-v-7d0e0e50]{width:100%;height:100%;overflow-y:scroll}.cards-container[data-v-7d0e0e50]{width:100%;min-height:calc(100vh - 48px);height:fit-content;justify-content:center;align-items:center;padding:80px 0}.form-card[data-v-7d0e0e50]{cursor:pointer}.form-card[data-v-7d0e0e50]:hover{box-shadow:0 0 10px #0000001a}.runner[data-v-7d0e0e50]{width:100%;height:100%;position:relative;display:flex;flex-direction:column;align-items:center;justify-content:center}
