import{g as m}from"./api.66aa9b15.js";import{u as p}from"./index.8b944c64.js";import{d as c,eM as d,eG as f,u as r,b as u,c as _,w as l,eA as y,f as b,E as g}from"./outputWidgets.52571dac.js";import{_ as h}from"./Login.vue_vue_type_script_setup_true_lang.973f1fac.js";import{a as w}from"./asyncComputed.2a2a1288.js";import{W as I}from"./WidgetsFrame.6587888f.js";import"./runnerData.3982af84.js";import"./url.5cc70021.js";import"./fetch.9dae2a64.js";import"./pubsub.be7004e9.js";import"./Link.a6766c40.js";import"./Base.e64db743.js";import"./index.1b528fc3.js";import"./Paragraph.7aa2ce32.js";import"./Text.0586c869.js";import"./Title.8fbc2e7d.js";import"./CircularLoading.49007855.js";import"./index.7797c9cd.js";import"./PhArrowClockwise.vue.b5de7a26.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="88992eb8-9aee-46bd-bde4-2c6f4beda13a",e._sentryDebugIdIdentifier="sentry-dbid-88992eb8-9aee-46bd-bde4-2c6f4beda13a")}catch{}})();const k=c({__name:"Login",setup(e){const t=d(),a=f(),{result:o}=w(m),i=async()=>{await p.signUp();const{redirect:s,...n}=a.query;if(s){await t.push({path:s,query:n,params:a.params});return}t.push({name:"playerHome",query:n})};return(s,n)=>r(o)?(u(),_(I,{key:0,"main-color":r(o).mainColor,theme:r(o).theme,"font-family":r(o).fontFamily,class:"runner"},{default:l(()=>[b(h,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):y("",!0)}});const j=g(k,[["__scopeId","data-v-b7ca18fc"]]);export{j as default};
//# sourceMappingURL=Login.d07e7d45.js.map
