import{C as c}from"./ContentLayout.34675bf7.js";import{d as l,L as k,z as m,r as g,b as r,c as n,w as d,f as i,u as t,eA as b}from"./outputWidgets.52571dac.js";import{K as _,_ as w,E as v,a as K}from"./TableView.vue_vue_type_script_setup_true_lang.544bdf0d.js";import{A as u,T as R}from"./TabPane.dea34545.js";import"./fetch.9dae2a64.js";import"./workspaces.daf256e7.js";import"./asyncComputed.2a2a1288.js";import"./runnerData.3982af84.js";import"./url.5cc70021.js";import"./record.2a93f29c.js";import"./pubsub.be7004e9.js";import"./scripts.3d09400f.js";import"./api.216daf4b.js";import"./metadata.baee0e00.js";import"./PhCheckCircle.vue.67b14c02.js";import"./PhKanban.vue.bce4e3b1.js";import"./PhScroll.vue.9f99ffd4.js";import"./PhWebhooksLogo.vue.5cbb3f37.js";import"./ant-design.903f71e5.js";import"./index.109082a3.js";import"./Modal.514213ca.js";import"./Text.0586c869.js";import"./Base.e64db743.js";import"./index.89edc4ba.js";import"./index.f3e1df2a.js";import"./index.88e4e5a7.js";import"./Paragraph.7aa2ce32.js";import"./index.1b528fc3.js";import"./Link.a6766c40.js";import"./Title.8fbc2e7d.js";import"./index.c5a1a3a3.js";import"./CollapsePanel.0c4aeafd.js";import"./index.6763f634.js";import"./index.eb4443e5.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.9a92c678.js";import"./Card.d78b977b.js";import"./LoadingOutlined.aa9a6bdf.js";import"./index.64231e4f.js";import"./Form.9e43a28b.js";import"./hasIn.f1c353ba.js";import"./string.256d79cc.js";import"./PlusOutlined.cf52d035.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="aff329e7-8ed1-4dba-a502-5cc0324430d8",e._sentryDebugIdIdentifier="sentry-dbid-aff329e7-8ed1-4dba-a502-5cc0324430d8")}catch{}})();const yt=l({__name:"WorkflowThreads",setup(e){const o=new v,p=new K,f=new k(m.array(m.string()),"kanban-selected-stages"),a=g("kanban");return(T,s)=>(r(),n(c,{"full-width":""},{default:d(()=>[i(t(R),{activeKey:a.value,"onUpdate:activeKey":s[0]||(s[0]=y=>a.value=y)},{default:d(()=>[i(t(u),{key:"kanban",tab:"Kanban View"}),i(t(u),{key:"table",tab:"Table View"})]),_:1},8,["activeKey"]),a.value==="kanban"?(r(),n(_,{key:0,"kanban-repository":t(o),"kanban-stages-storage":t(f),"stage-run-repository":t(p)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):b("",!0),a.value==="table"?(r(),n(w,{key:1,"kanban-repository":t(o)},null,8,["kanban-repository"])):b("",!0)]),_:1}))}});export{yt as default};
//# sourceMappingURL=WorkflowThreads.b684db31.js.map
