import{Y as s,f as d,V as p}from"./outputWidgets.52571dac.js";import{B as f,b as i}from"./Base.e64db743.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="3d40fc48-52ec-4a1d-aad9-04ae8d167108",a._sentryDebugIdIdentifier="sentry-dbid-3d40fc48-52ec-4a1d-aad9-04ae8d167108")}catch{}})();const c=()=>p(i(),["component"]),r=(a,e)=>{let{slots:t,attrs:o}=e;const n=s(s(s({},a),{component:"div"}),o);return d(f,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=c();const l=r;export{l as A};
//# sourceMappingURL=Paragraph.7aa2ce32.js.map
