import{u as n}from"./index.8b944c64.js";import"./outputWidgets.52571dac.js";import{r as s,w as a}from"./runnerData.3982af84.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e9fa11a3-dd2c-4eeb-9dcd-25d0de362082",e._sentryDebugIdIdentifier="sentry-dbid-e9fa11a3-dd2c-4eeb-9dcd-25d0de362082")}catch{}})();async function f(e){const t=await fetch(`/_pages/${e}`,{headers:n.authHeaders()});if(t.status===404)return null;if(!t.ok)throw new Error(await t.text());const{form:r}=await t.json();return r?s(r):null}async function i(){const e=await fetch("/_workspace",{headers:n.authHeaders()});if(e.status!=200)return a({});const t=await e.json();return a(t)}export{f,i as g};
//# sourceMappingURL=api.66aa9b15.js.map
