import{d as f,eG as _,eM as p,b as u,ey as m,f as i,w as r,u as s,c as y,eA as g,au as n,eJ as c,bI as b,E as h}from"./outputWidgets.52571dac.js";import{A as w}from"./Title.8fbc2e7d.js";import{a as k}from"./Base.e64db743.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new x().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="93cf320a-0723-4ee9-b803-5415d92c5d28",e._sentryDebugIdIdentifier="sentry-dbid-93cf320a-0723-4ee9-b803-5415d92c5d28")}catch{}})();const I={class:"inner-content"},v=f({__name:"Error",setup(e){const t=_(),d=p(),o=()=>{const{status:a}=t.params;switch(a){case"404":return{status:a,title:"Page not found",message:"We couldn't find the page you were looking for."};case"403":return{status:a,title:"Access denied",message:"You tried to access a page you did not have prior authorization for. Please contact your administrator.",action:"Go back to home"};default:return{status:"500",title:"Internal server error",message:"An unknown error ocurred. Please try again or contact support."}}},l=()=>{d.push({name:"playerHome"})};return(a,A)=>(u(),m("div",I,[i(s(w),null,{default:r(()=>[n(c(o().title),1)]),_:1}),i(s(k),{class:"message"},{default:r(()=>[n(c(o().message),1)]),_:1}),o().action?(u(),y(s(b),{key:0,type:"primary",onClick:l},{default:r(()=>[n(c(o().action),1)]),_:1})):g("",!0)]))}});const x=h(v,[["__scopeId","data-v-c0d26e3f"]]);export{x as default};
//# sourceMappingURL=Error.2734d54f.js.map
