import{O as i}from"./index.8b944c64.js";import{A as s}from"./Title.8fbc2e7d.js";import"./index.1b528fc3.js";import{A as l}from"./Text.0586c869.js";import{d as f,o as u,b as c,ey as m,f as o,w as r,u as n,au as a}from"./outputWidgets.52571dac.js";import"./fetch.9dae2a64.js";import"./pubsub.be7004e9.js";import"./Base.e64db743.js";import"./Link.a6766c40.js";import"./Paragraph.7aa2ce32.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6d2952e6-3ff0-424e-9683-ff55dd98bc6d",e._sentryDebugIdIdentifier="sentry-dbid-6d2952e6-3ff0-424e-9683-ff55dd98bc6d")}catch{}})();const x=f({__name:"OidcLoginCallback",setup(e){return u(async()=>{await new i().loginCallback()}),(t,d)=>(c(),m("div",null,[o(n(s),null,{default:r(()=>[a("You're authenticated")]),_:1}),o(n(l),null,{default:r(()=>[a(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{x as default};
//# sourceMappingURL=OidcLoginCallback.d42acbfd.js.map
