import{a as e,B as s}from"./Base.e64db743.js";import{A as a}from"./Link.a6766c40.js";import{A as o}from"./Paragraph.7aa2ce32.js";import{A as r}from"./Text.0586c869.js";import{A as i}from"./Title.8fbc2e7d.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="2ae712c6-358c-42d9-8772-a184a242bc43",n._sentryDebugIdIdentifier="sentry-dbid-2ae712c6-358c-42d9-8772-a184a242bc43")}catch{}})();e.Text=r;e.Title=i;e.Paragraph=o;e.Link=a;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,r),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,o),n.component(e.Link.displayName,a),n};
//# sourceMappingURL=index.1b528fc3.js.map
