import{d as y,ex as b,N as m,b as d,ey as l,e as c,u as g,ez as r,dq as u,eA as w,eB as h,eC as S,E as v,r as k,a as C,f,w as I,aG as x}from"./outputWidgets.52571dac.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="aa077589-87a7-40eb-8ce3-947dbe55fea1",e._sentryDebugIdIdentifier="sentry-dbid-aa077589-87a7-40eb-8ce3-947dbe55fea1")}catch{}})();const B=y({__name:"Modal",props:{containerStyle:{},headerStyle:{},contentStyle:{}},emits:["open","close"],setup(e,{expose:s,emit:o}){const i=b(),_=()=>{a.isOpened=!0,o("open")},n=()=>{a.isOpened=!1,o("close")};s({open:_,close:n});const a=m({isOpened:!1});return(t,p)=>(d(),l("div",{class:S(["background",a.isOpened&&"visible"]),onClick:n},[c("div",{class:"container",style:r(t.containerStyle),onClick:p[0]||(p[0]=h(()=>{},["stop"]))},[g(i).header?(d(),l("div",{key:0,class:"header",style:r(t.headerStyle)},[u(t.$slots,"header",{},void 0,!0)],4)):w("",!0),c("div",{class:"content",style:r(t.contentStyle)},[u(t.$slots,"content",{},void 0,!0)],4)],4)],2))}});const D=v(B,[["__scopeId","data-v-4d878495"]]),M=["src"],N=y({__name:"Home",setup(e){const s=m({onboardingForm:""}),o=k(null);return(i,_)=>{const n=C("router-view");return d(),l(x,null,[f(n,{class:"router"}),f(D,{ref_key:"modal",ref:o},{content:I(()=>[c("iframe",{class:"form",src:s.onboardingForm},null,8,M)]),_:1},512)],64)}}});const z=v(N,[["__scopeId","data-v-7e290e34"]]);export{z as default};
//# sourceMappingURL=Home.7d1478e1.js.map
