import{B as f}from"./BookOutlined.7e4ac738.js";import{d,b as a,c,w as o,f as l,u as n,dq as u,ey as i,au as p,aG as b,bI as y}from"./outputWidgets.52571dac.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="5940f181-571c-4775-8f6c-90f0cb2af046",t._sentryDebugIdIdentifier="sentry-dbid-5940f181-571c-4775-8f6c-90f0cb2af046")}catch{}})();const k=d({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return a(),c(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:o(()=>[l(n(f))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(a(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{k as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.a5567333.js.map
