import{Y as s}from"./outputWidgets.52571dac.js";import{c as i,d as c}from"./index.a28cfbb3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="65444300-d426-4d86-9399-5d5746ede4a0",e._sentryDebugIdIdentifier="sentry-dbid-65444300-d426-4d86-9399-5d5746ede4a0")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:m,TimePicker:f,QuarterPicker:o,RangePicker:d}=i(c),g=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:m,RangePicker:d,TimePicker:f,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(d.name,d),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{g as D,t as M,o as Q,d as R,r as W};
//# sourceMappingURL=dayjs.4eefb4f6.js.map
