import{u}from"./index.8b944c64.js";import{d as y,L as l,z as p,r as _,b as o,ey as k,f as n,w as g,u as e,c as m,eA as d,E as v}from"./outputWidgets.52571dac.js";import{K as w,_ as T,P as K,b as h}from"./TableView.vue_vue_type_script_setup_true_lang.544bdf0d.js";import{A as b,T as I}from"./TabPane.dea34545.js";import"./Card.d78b977b.js";import"./fetch.9dae2a64.js";import"./pubsub.be7004e9.js";import"./workspaces.daf256e7.js";import"./asyncComputed.2a2a1288.js";import"./runnerData.3982af84.js";import"./url.5cc70021.js";import"./record.2a93f29c.js";import"./scripts.3d09400f.js";import"./api.216daf4b.js";import"./metadata.baee0e00.js";import"./PhCheckCircle.vue.67b14c02.js";import"./PhKanban.vue.bce4e3b1.js";import"./PhScroll.vue.9f99ffd4.js";import"./PhWebhooksLogo.vue.5cbb3f37.js";import"./ant-design.903f71e5.js";import"./index.109082a3.js";import"./Modal.514213ca.js";import"./Text.0586c869.js";import"./Base.e64db743.js";import"./index.89edc4ba.js";import"./index.f3e1df2a.js";import"./index.88e4e5a7.js";import"./Paragraph.7aa2ce32.js";import"./index.1b528fc3.js";import"./Link.a6766c40.js";import"./Title.8fbc2e7d.js";import"./index.c5a1a3a3.js";import"./CollapsePanel.0c4aeafd.js";import"./index.6763f634.js";import"./index.eb4443e5.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.9a92c678.js";import"./LoadingOutlined.aa9a6bdf.js";import"./index.64231e4f.js";import"./Form.9e43a28b.js";import"./hasIn.f1c353ba.js";import"./string.256d79cc.js";import"./PlusOutlined.cf52d035.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="f0fbf2a3-353d-41d0-8df0-3f87e59824c5",t._sentryDebugIdIdentifier="sentry-dbid-f0fbf2a3-353d-41d0-8df0-3f87e59824c5")}catch{}})();const R={class:"threads-view"},x=y({__name:"Threads",setup(t){const a=new K(u),s=new h,c=new l(p.array(p.string()),"kanban-selected-stages"),r=_("kanban");return(B,i)=>(o(),k("div",R,[n(e(I),{activeKey:r.value,"onUpdate:activeKey":i[0]||(i[0]=f=>r.value=f)},{default:g(()=>[n(e(b),{key:"kanban",tab:"Kanban View"}),n(e(b),{key:"table",tab:"Table View"})]),_:1},8,["activeKey"]),r.value==="kanban"?(o(),m(w,{key:0,"kanban-repository":e(a),"kanban-stages-storage":e(c),"stage-run-repository":e(s)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):d("",!0),r.value==="table"?(o(),m(T,{key:1,"kanban-repository":e(a)},null,8,["kanban-repository"])):d("",!0)]))}});const ke=v(x,[["__scopeId","data-v-b0fcb81e"]]);export{ke as default};
//# sourceMappingURL=Threads.9fb46eb9.js.map
