.flex-row[data-v-961eed86]{display:flex;flex-direction:row;align-items:center;justify-content:right;gap:5px;height:100%;width:100%}.trigger-buttons[data-v-7d24d598]{display:flex;gap:8px;font-size:14px;color:gray}.trigger-buttons>*[data-v-7d24d598]{cursor:pointer}.trigger-buttons>*[data-v-7d24d598] :hover{color:#f28392}.trigger-buttons>*[data-v-7d24d598] :active{color:#f28392}.centered[data-v-7d24d598]{display:flex;flex-direction:column;gap:16px;padding:32px}.icon[data-v-7d24d598]{margin:0 0 -2px 4px}
