import{P as y}from"./PlayerNavbar.fd170b6e.js";import{g as b}from"./api.66aa9b15.js";import{u as r}from"./index.8b944c64.js";import{d as v,eM as h,r as w,O as k,a as I,b as s,ey as n,f as i,u as p,E as L}from"./outputWidgets.52571dac.js";import{a as M}from"./asyncComputed.2a2a1288.js";import{L as x}from"./CircularLoading.49007855.js";import"./metadata.baee0e00.js";import"./PhCheckCircle.vue.67b14c02.js";import"./PhKanban.vue.bce4e3b1.js";import"./PhScroll.vue.9f99ffd4.js";import"./PhWebhooksLogo.vue.5cbb3f37.js";import"./PhSignOut.vue.2dbc88f8.js";import"./index.07ea88e4.js";import"./Text.0586c869.js";import"./Base.e64db743.js";import"./runnerData.3982af84.js";import"./url.5cc70021.js";import"./fetch.9dae2a64.js";import"./pubsub.be7004e9.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="23783ec1-a4a4-4760-9e69-0d2aa68dc7ab",o._sentryDebugIdIdentifier="sentry-dbid-23783ec1-a4a4-4760-9e69-0d2aa68dc7ab")}catch{}})();const D={class:"main-container"},C={key:0,class:"centered"},E={key:1,class:"content"},N=v({__name:"Main",setup(o){const e=h(),t=w(r.getUser());r.pubsub.subscribe("authenticated",a=>{t.value=a});const u=({path:a})=>{e.push({path:`/${a}`})},d=()=>{e.push({name:"playerLogin"})},{result:m,loading:_,refetch:l}=M(b);k(t,l);const f=()=>{r.removeUser(),e.push({name:"playerHome"})};return(a,B)=>{var c;const g=I("router-view");return s(),n("div",D,[i(y,{"runner-data":p(m),"user-email":(c=t.value)==null?void 0:c.claims.email,onNavigate:u,onLogout:f,onLogin:d},null,8,["runner-data","user-email"]),p(_)?(s(),n("div",C,[i(x)])):(s(),n("section",E,[i(g)]))])}}});const X=L(N,[["__scopeId","data-v-725e3c45"]]);export{X as default};
//# sourceMappingURL=Main.391960c3.js.map
