.inner-content[data-v-c0d26e3f]{display:flex;justify-content:center;align-items:center;flex-direction:column;height:100%}.message[data-v-c0d26e3f]{width:400px;text-align:center;font-size:16px;margin-bottom:40px}
